@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -107,6 +107,9 @@ INVALIDPARAMETER_DUPLICATEDLBTRAFFICMIRRORCOLLECTORS = 'InvalidParameter.Duplica
 # 指定过滤条件不存在。
 INVALIDPARAMETER_FILTERINVALIDKEY = 'InvalidParameter.FilterInvalidKey'
 
+# 指定过滤选项缺失
+INVALIDPARAMETER_FILTERMISSPARAMETER = 'InvalidParameter.FilterMissParameter'
+
 # 指定过滤条件不是键值对。
 INVALIDPARAMETER_FILTERNOTDICT = 'InvalidParameter.FilterNotDict'
 
@@ -752,6 +755,9 @@ RESOURCENOTFOUND_SVCNOTEXIST = 'ResourceNotFound.SvcNotExist'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 获取CDC IDC VIP失败.
+RESOURCEUNAVAILABLE_FAILEDGETCDCIDCVIP = 'ResourceUnavailable.FailedGetCdcIdcVip'
+
 # 当前用户不在指定终端节点服务的白名单内。
 RESOURCEUNAVAILABLE_SERVICEWHITELISTNOTADDED = 'ResourceUnavailable.ServiceWhiteListNotAdded'
 
@@ -1232,6 +1238,9 @@ UNSUPPORTEDOPERATION_RESOURCEISINVALIDSTATE = 'UnsupportedOperation.ResourceIsIn
 # 输入的资源ID与IP绑定的资源不匹配，请检查。
 UNSUPPORTEDOPERATION_RESOURCEMISMATCH = 'UnsupportedOperation.ResourceMismatch'
 
+# 资源正在操作中，请稍后重试。
+UNSUPPORTEDOPERATION_RESOURCEPROCESSING = 'UnsupportedOperation.ResourceProcessing'
+
 # 未找到相关角色，请确认角色是否授权。
 UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
 
